# [TexnoMagic docs online][docs]

## [TexnoMagic docs on GitLab](https://github.com/texnoforge/texnomagic/tree/master/docs)

## TexnoMagic docs offline

See docs/README.md and other files in docs/ directory.

You can also render docs into HTML using mkdocs:

    pip install mkdocs
    mkdocs build
    browser site/index.html

#### read the [docs] and have a nice magic ᕕ( ᐛ )ᕗ

[docs]: http://texnoforge.github.io/texnomagic
